@@ -9,4 +9,9 @@ except ImportError:
 try:
     import sql
 except ImportError:
-    print "SQL could not be loaded."
\ No newline at end of file
+    print "SQL could not be loaded."
+
+try:
+    import csv
+except ImportError:
+    print "CSV could not be loaded."
\ No newline at end of file
